@@ -181,6 +181,7 @@ plot.expression <- function(x, ...) {
   "\\SPACE2@", "phantom(0)",
   "\\,", "phantom(0)",
   "\\;", "phantom() ~~ phantom()",
+  "\\phantom", "phantom(@1@)",
 
   # Specials
   "\\COMMA@", "','",
@@ -274,7 +275,6 @@ toString.latextoken <- function(x, ...) {
   else
     p <- str_c(p, toString(tok$succ))
 
-  #p <- str_replace_all(p, "''", '')
   return(p)
 }
 
@@ -307,7 +307,8 @@ toString.latextoken <- function(x, ...) {
 ## Returns an expression by default; can either return 'character' (return the expression
 ## as a string) or 'ast' (returns the tree as parsed from the LaTeX string; useful for debug).
 .parseTeX <-
-  function(string, output = c('expression', 'character', 'ast')) {
+  function(string, bold=FALSE, italic=FALSE, output = c('expression', 'character', 'ast')) {
+    output <- match.arg(output)
     original <- string
     # Create the root node
     textmode <- TRUE
@@ -409,7 +410,7 @@ toString.latextoken <- function(x, ...) {
         old <- token
         token <- .token(parent = old, ch = ch, textmode = textmode)
         old$args[[length(old$args) + 1]] <- token
-      } else if (ch == "}" || ch == "]" && !prevch == "\\") {
+      } else if ((ch == "}" || ch == "]") && !prevch == "\\") {
         # Square or brace parameter ended, return to parent node
         token <- token$parent
         needsnew <- TRUE
@@ -488,22 +489,27 @@ toString.latextoken <- function(x, ...) {
     }
 
     post_process(root)
-    if (output[1] == 'ast')
+    if (output == 'ast')
       return(root)
 
-    
     str <- toString(root)
+    if (bold && italic) {
+      str <- paste0("bolditalic(", str, ")")
+    } else if (bold) {
+      str <- paste0("bold(", str, ")")
+    } else if (italic) {
+      str <- paste0("italic(", str, ")")
+    }
+    
     exp <- tryCatch(
       parse(text = str), error = function(e) {
-        cat("Original string: ", original, "\n")
-        cat("Parsed expression: ", str, "\n")
+        message("Original string: ", original)
+        message("Parsed expression: ", str)
         stop(e)
       }
     )
-    
-    
 
-    if (output[1] == 'character') {
+    if (output == 'character') {
       return(str)
     } else
       return(exp)
@@ -524,7 +530,9 @@ latex2exp <-
 #' Converts a LaTeX string to a \code{\link{plotmath}} expression.
 #'
 #' @param string A character vector containing LaTeX expressions. Note that any backslashes must be escaped (e.g. "$\\alpha").
-#' @param output The returned object, one of "expression" (default, returns a plotmath expression ready for plotting), "text" (returns the expression as a string), and "ast" (returns the tree used to generate the expression).
+#' @param bold   Whether to make the entire label bold
+#' @param italic Whether to make the entire label italic
+#' @param output The returned object, one of "expression" (default, returns a plotmath expression ready for plotting), "character" (returns the expression as a string), and "ast" (returns the tree used to generate the expression).
 #'
 #' @return Returns an expression (see the \code{output} parameter).
 #'
@@ -536,10 +544,8 @@ latex2exp <-
 #' plot(a, a^2, xlab=TeX("$\\alpha$"), ylab=TeX("$\\alpha^2$"))
 #' @export
 TeX <-
-  function(string, output = c('expression', 'text', 'ast')) {
-    if (missing(string))
-      stop("Specify a LaTeX string.")
-    return(sapply(string, .parseTeX, output = output))
+  function(string, bold=FALSE, italic=FALSE, output = c('expression', 'character', 'ast')) {
+    return(sapply(string, .parseTeX, bold=bold, italic=italic, output = output))
   }
 
 #' Returns a list of all supported LaTeX symbols and expressions that can be converted with \code{\link{latex2exp}}.
@@ -613,10 +619,10 @@ latex2exp_supported <- function(plot = FALSE) {
           sym <- str_c(sym, "{y}")
       }
       sym <- str_c("$", sym, "$")
-      text(col, rows - row, sym, family = 'mono', pos = 4)
+      text(col, rows - row, sym, family = 'mono', pos = 4, cex=0.7)
 
       try(text(col + 0.6, rows - row,
-               TeX(sym), pos = 4, offset = offset))
+               TeX(sym), pos = 4, offset = offset, cex=0.7))
       row <- row + 1
     }
 
@@ -647,15 +653,15 @@ latex2exp_examples <- function() {
     "\\textbf{Bold} and \\textit{italic} text!",
     "$\\left{\\left(\\left[BRACES\\right]\\right)\\right}$",
     "Whitespace compliant: $x ^ 2 \\times \\sum_ 0 ^ 1 y _ i$",
-    "Numbers: $0.05$, $0.03$, $0.005^{0.002}_{0.01}$"
+    "Numbers: $0.05$, $0.03$, $0.005^{0.002}_{0.01}$",
+    "Phantom: $a\\phantom{test}b$"
   )
 
   x <- 0
   y <- seq(0.95, 0.05, length.out = length(examples))
 
   text(
-    0.5, y, sapply(examples, function(e)
-      str_replace_all(e, "\\\\", "\\\\\\\\")), pos = 2, cex = 0.7, family = 'mono'
+    0.5, y, examples, pos = 2, cex = 0.5, family = 'mono'
   )
   text(0.5, y, TeX(examples), pos = 4)
   return(TRUE)
